==> usermin-1.840.tar.gz: usermin-1.840/mailbox/uconfig.info.el <==
line0=Περιβάλλον διεπαφής χρήστη,11
perpage=Εμφάνιση μηνύματων email ανά σελίδα,0,5
top_buttons=Εμφάνιση κουμπιών στο πάνω μέρος για,1,2-Γραμματοθυρίδες και emails,1-Γραμματοθυρίδες μόνο,0-Ποτέ
arrows=Εμφάνιση βελών αλλαγής σελίδας στο κάτω μέρος για,1,2-Γραμματοθυρίδες και emails,1-Γραμματοθυρίδες μόνο,0-Ποτέ
show_to=Εμφάνιση διεύθυνσης Προς: στις γραμματοθυρίδες;,1,1-Ναι,0-Όχι
refresh=Δευτερόλεπτα μεταξύ διαδοχικών ανανεώσεων περιεχομένου γραμματοθυρίδας,3,Να μην γίνεται ανανέωση
open_mode=Άνοιγμα μηνυμάτων σε,1,1-Νέο παράθυρο,0-Στο παράθυρο της λίστας
show_body=Εμφάνιση προεπισκοπίσεων σώματος μηνύματος στην λίστα;,1,1-Ναι,0-Όχι
wrap_width=Πλάτος αναδίπλωσης μηνυμάτων email σε,0,5
auto_mark=Αυτόματη σημείωση αναγνωσμένων μυνημάτων;,1,1-Ναι,0-Όχι
view_html=Εμφανιση κειμένου μηνύματος ως,4,0-Πάντα απλό κείμενο,1-Κείμενο εάν είναι δυνατόν&#44; HTML αλλιώς,2-HTML αν είναι δυνατόν&#44; κείμενο αλλιώς,3-Μετατροπή HTML σε απλό κείμενο
head_html=Συμπερίληψη HTML τομέα &lt;head&gt; μηνύματος στην σελίδα;,1,1-Ναι,0-Όχι
check_mod=Έλεγχος αλλαγών στην γραμματοθυρίδα κατά την διαγραφή email;,1,1-Ναι,0-Όχι
link_mode=Άνοιγμα συνδέσμων σε,1,1-Νέο παράθυρο,0-Ίδιο παράθυρο
html_edit=Χρήση επεξεργαστή HTML για σύνθεση;,1,2-Πάντα,1-Κατά την απάντηση σε HTML email,0-Ποτέ
html_quote=HTML τρόπος εμφάνισης εισαγωγικών,1,1-Το μήνυμα απο κάτω &lt;hr&gt;,0-Το μήνυμα μέσα &lt;blockquote&gt;
spell_check=Ενεργοποίηση ελέγχου ορθογραφίας προκαθορισμένα;,1,1-Ναι,0-Όχι
line1=Αποστολή ,11
no_mime=Αποστολή μυνημάτων απλού κειμένου όποτε είναι αυτό δυνατό;,1,1-Ναι,0-Όχι
save_sent=Αποθήκευση απεσταλμένων email;,1,1-Ναι,0-Όχι
real_name=Συμπερίληψη πραγματικού ονόματος στην διεύθυνση Από: ;,1,1-Ναι,0-Όχι
charset=Κωδικοποίηση χαρακτήρων απεσταλμένου μηνύματος
sig_file=Αρχείο υπογραφής,10,*-Κανένα,.signature-~/.signature,Άλλο αρχείο
fwd_mode=Προώθηση μυνημάτων με εισαγωγικά κειμένου;,1,0-Ναι,1-Όχι
from_in_to=Εμφάνιση διεύθυνσης Από: όταν επιλέγεται μια διεύθυνση Προς: ;,1,1-Ναι,0-Όχι
sort_addrs=Ταξινόμιση βιβλίου διευθύνσεων κατά,1,0-Σειρά προσθήκης,1-Πραγματικό όνομα,2-Διεύθυνση email
reply_to=Διεύθυνση Απάντησης: ,10,x-Καμία,*-Επιλογή κατά την αποστολή,Διεύθυνση..
bcc_to=Κρυφή Κοινοποίηση: αποστολή μηνυμάτων σε,0
add_abook=Προσθήκη παραληπτών email στο βιβλίο διευθύνσεων;,1,1-Ναι,0-Όχι
real_expand=Αναζήτηση πραγματικών ονομάτων κατά την αποστολή;,1,1-Ναι,0-Όχι
force_subject=Ενέργεια εάν το θέμα του εξερχόμενου email λείπει,10,-Να μη γίνεται τίποτα,error-Εμφάνιση μηνύματος λάθους,Ορισμός σε
send_return=Μετά την αποστολή email&#44; εμφάνισε την,1,1-Λίστα των email,0-Σελίδα αποστολής email
self_crypt=Κρυπτογράφηση επίσης του email&#44; με το κρυφό σας κλειδί;,1,1-Ναι,0-Όχι
req_dsn=Να ζητούνται ενημερώσεις κατάστασης ανάγνωσης;,1,1-Πάντα,2-Προεραιτικά,0-Όχι
send_dsn=Απάντηση σε αιτήματα κατάστασης ανάγνωσης;,1,1-Αυτόματα,2-Χειρωκίνητα,0-Όχι
req_del=Να ζητούνται ενημερώσεις παράδοσης;,1,1-Πάντα,2-Προεραιτικά,0-Όχι
date_fmt=Τρόπος εμφάνισης ημερομηνίας στο email list,1,dmy-DD/MM/YYYY,mdy-MM/DD/YYYY,ymd-YYYY/MM/DD
date_tz=Ζώνη ώρας για εμφάνιση ημερομηνιών,3,Προκαθορισμένη Συστήματος
line3=Φάκελοι email,11
mailbox_recur=Χειρισμός υποφακέλων γραμματοθυρίδων ως,1,1-Φάκελοι,0-Υποφάκελοι
default_folder=Προκαθορισμένο αρχείο φακέλου,3,Εισερχόμενα
folder_sort=Τύπος ταξινόμησης φακέλων,4,0-Εσωτερικά&#44; μετά ~/mail&#44; μετά εξωτερικά,1-Εσωτερικά&#44; μετά ταξινόμηση υπολοίπων κατά όνομα,2-Όλα ταξινομημένα κατά όνομα
sent_name=Αρχείο φακέλου απεσταλμένων μηνυμάτων,3,Αυτόματο
drafts_name=Αρχείο φακέλου πρόχειρων μηνυμάτων,3,Αυτόματο
related_search=Αναζήτηση για ίδιο θέμα ή αποστολέα σε ,1,1-Όλους τους φακέλους,2-Όλους τους τοπικούς φακέλους,0-Τρέχον φάκελο
search_latest=Μηνύματα προς αναζήτηση,10,-Όλα τα μηνύματα,Μόνο τα τελευταία
mailbox_dir=Φάκελος γραμματοθυρίδων κάτω από τον προσωπικό φάκελο χρήστη,0,30
delete_warn=Ερώτηση επιβεβαίωσης πριν την διαγραφή;,10,y-Ναι,n-Όχι,Για αρχεία mbox μεγαλύτερα από
delete_mode=Κατά την διαγραφή email,1,0-Απλά διέγραψε από το αρχεί email,1-Μετακίνηση στον φάκελο απορριμάτων
show_delall=Εμφάνιση κουμπιού διαγραφής όλης της γραμματοθυρίδας;,1,1-Ναι,0-Όχι
line4=Επιλογές Spam,11
spam_buttons=Εμφάνιση κουμπιών σημείωσης ως spam για,2,list-Γραμματοθυρίδες,mail-Μηνύματα
ham_buttons=Εμφάνιση κουμπιών σημείωσης ως ham για,2,list-Γραμματοθυρίδες,mail-Μηνύματα
spam_del=Διαγραφή spam κατά την σημείωση;,1,1-Ναι,0-Όχι
white_book=Προσθήκη όλων των εγγραφών του βιβλίου διευθύνσεων στην λίστα επιτρεπτών αποστολέων (whitelist);,1,1-Ναι,0-Όχι
line5=Επιλογές συνημμένων,11
thumbnails=Εμφάνιση εικόνων συνημμένων ως μικρά εικονίδια;,1,1-Ναι,0-Όχι
def_attach=Προκαθορισμένος αριθμός συνημμένων προς αποστολή,0,8

==> usermin-2.520.tar.gz: usermin-2.520/mailbox/uconfig.info.el <==
line0=Περιβάλλον διεπαφής χρήστη,11
perpage=Εμφάνιση μηνύματων email ανά σελίδα,0,5
top_buttons=Εμφάνιση κουμπιών στο πάνω μέρος για,1,2-Γραμματοθυρίδες και emails,1-Γραμματοθυρίδες μόνο,0-Ποτέ
arrows=Εμφάνιση βελών αλλαγής σελίδας στο κάτω μέρος για,1,2-Γραμματοθυρίδες και emails,1-Γραμματοθυρίδες μόνο,0-Ποτέ
show_to=Εμφάνιση διεύθυνσης Προς: στις γραμματοθυρίδες;,1,1-Ναι,0-Όχι
refresh=Δευτερόλεπτα μεταξύ διαδοχικών ανανεώσεων περιεχομένου γραμματοθυρίδας,3,Να μην γίνεται ανανέωση
open_mode=Άνοιγμα μηνυμάτων σε,1,1-Νέο παράθυρο,0-Στο παράθυρο της λίστας
show_body=Εμφάνιση προεπισκοπίσεων σώματος μηνύματος στην λίστα;,1,1-Ναι,0-Όχι
wrap_width=Πλάτος αναδίπλωσης μηνυμάτων email σε,0,5
auto_mark=Αυτόματη σημείωση αναγνωσμένων μυνημάτων;,1,1-Ναι,0-Όχι
view_html=Εμφανιση κειμένου μηνύματος ως,4,0-Πάντα απλό κείμενο,1-Κείμενο εάν είναι δυνατόν&#44; HTML αλλιώς,2-HTML αν είναι δυνατόν&#44; κείμενο αλλιώς,3-Μετατροπή HTML σε απλό κείμενο
check_mod=Έλεγχος αλλαγών στην γραμματοθυρίδα κατά την διαγραφή email;,1,1-Ναι,0-Όχι
link_mode=Άνοιγμα συνδέσμων σε,1,1-Νέο παράθυρο,0-Ίδιο παράθυρο
html_edit=Χρήση επεξεργαστή HTML για σύνθεση;,1,2-Πάντα,1-Κατά την απάντηση σε HTML email,0-Ποτέ
html_quote=HTML τρόπος εμφάνισης εισαγωγικών,1,1-Το μήνυμα απο κάτω &lt;hr&gt;,0-Το μήνυμα μέσα &lt;blockquote&gt;
spell_check=Ενεργοποίηση ελέγχου ορθογραφίας προκαθορισμένα;,1,1-Ναι,0-Όχι
line1=Αποστολή ,11
no_mime=Αποστολή μυνημάτων απλού κειμένου όποτε είναι αυτό δυνατό;,1,1-Ναι,0-Όχι
save_sent=Αποθήκευση απεσταλμένων email;,1,1-Ναι,0-Όχι
real_name=Συμπερίληψη πραγματικού ονόματος στην διεύθυνση Από: ;,1,1-Ναι,0-Όχι
charset=Κωδικοποίηση χαρακτήρων απεσταλμένου μηνύματος
sig_file=Αρχείο υπογραφής,10,*-Κανένα,.signature-~/.signature,Άλλο αρχείο
fwd_mode=Προώθηση μυνημάτων με εισαγωγικά κειμένου;,1,0-Ναι,1-Όχι
from_in_to=Εμφάνιση διεύθυνσης Από: όταν επιλέγεται μια διεύθυνση Προς: ;,1,1-Ναι,0-Όχι
sort_addrs=Ταξινόμιση βιβλίου διευθύνσεων κατά,1,0-Σειρά προσθήκης,1-Πραγματικό όνομα,2-Διεύθυνση email
reply_to=Διεύθυνση Απάντησης: ,10,x-Καμία,*-Επιλογή κατά την αποστολή,Διεύθυνση..
bcc_to=Κρυφή Κοινοποίηση: αποστολή μηνυμάτων σε,0
add_abook=Προσθήκη παραληπτών email στο βιβλίο διευθύνσεων;,1,1-Ναι,0-Όχι
real_expand=Αναζήτηση πραγματικών ονομάτων κατά την αποστολή;,1,1-Ναι,0-Όχι
force_subject=Ενέργεια εάν το θέμα του εξερχόμενου email λείπει,10,-Να μη γίνεται τίποτα,error-Εμφάνιση μηνύματος λάθους,Ορισμός σε
send_return=Μετά την αποστολή email&#44; εμφάνισε την,1,1-Λίστα των email,0-Σελίδα αποστολής email
self_crypt=Κρυπτογράφηση επίσης του email&#44; με το κρυφό σας κλειδί;,1,1-Ναι,0-Όχι
req_dsn=Να ζητούνται ενημερώσεις κατάστασης ανάγνωσης;,1,1-Πάντα,2-Προεραιτικά,0-Όχι
send_dsn=Απάντηση σε αιτήματα κατάστασης ανάγνωσης;,1,1-Αυτόματα,2-Χειρωκίνητα,0-Όχι
req_del=Να ζητούνται ενημερώσεις παράδοσης;,1,1-Πάντα,2-Προεραιτικά,0-Όχι
date_fmt=Τρόπος εμφάνισης ημερομηνίας στο email list,1,auto-Locale based,dmy-DD/MM/YYYY,mdy-MM/DD/YYYY,ymd-YYYY/MM/DD
date_tz=Ζώνη ώρας για εμφάνιση ημερομηνιών,3,Προκαθορισμένη Συστήματος
line3=Φάκελοι email,11
mailbox_recur=Χειρισμός υποφακέλων γραμματοθυρίδων ως,1,1-Φάκελοι,0-Υποφάκελοι
default_folder=Προκαθορισμένο αρχείο φακέλου,3,Εισερχόμενα
folder_sort=Τύπος ταξινόμησης φακέλων,4,0-Εσωτερικά&#44; μετά ~/mail&#44; μετά εξωτερικά,1-Εσωτερικά&#44; μετά ταξινόμηση υπολοίπων κατά όνομα,2-Όλα ταξινομημένα κατά όνομα
sent_name=Αρχείο φακέλου απεσταλμένων μηνυμάτων,3,Αυτόματο
drafts_name=Αρχείο φακέλου πρόχειρων μηνυμάτων,3,Αυτόματο
related_search=Αναζήτηση για ίδιο θέμα ή αποστολέα σε ,1,1-Όλους τους φακέλους,2-Όλους τους τοπικούς φακέλους,0-Τρέχον φάκελο
search_latest=Μηνύματα προς αναζήτηση,10,-Όλα τα μηνύματα,Μόνο τα τελευταία
mailbox_dir=Φάκελος γραμματοθυρίδων κάτω από τον προσωπικό φάκελο χρήστη,0,30
delete_warn=Ερώτηση επιβεβαίωσης πριν την διαγραφή;,10,y-Ναι,n-Όχι,Για αρχεία mbox μεγαλύτερα από
delete_mode=Κατά την διαγραφή email,1,0-Απλά διέγραψε από το αρχεί email,1-Μετακίνηση στον φάκελο απορριμάτων
show_delall=Εμφάνιση κουμπιού διαγραφής όλης της γραμματοθυρίδας;,1,1-Ναι,0-Όχι
line4=Επιλογές Spam,11
spam_buttons=Εμφάνιση κουμπιών σημείωσης ως spam για,2,list-Γραμματοθυρίδες,mail-Μηνύματα
ham_buttons=Εμφάνιση κουμπιών σημείωσης ως ham για,2,list-Γραμματοθυρίδες,mail-Μηνύματα
spam_del=Διαγραφή spam κατά την σημείωση;,1,1-Ναι,0-Όχι
white_book=Προσθήκη όλων των εγγραφών του βιβλίου διευθύνσεων στην λίστα επιτρεπτών αποστολέων (whitelist);,1,1-Ναι,0-Όχι
line5=Επιλογές συνημμένων,11
thumbnails=Εμφάνιση εικόνων συνημμένων ως μικρά εικονίδια;,1,1-Ναι,0-Όχι
def_attach=Προκαθορισμένος αριθμός συνημμένων προς αποστολή,0,8
